@@ -2,7 +2,7 @@ from sys import path, argv
 from os import getcwd
 
 from . import commands
-from .repl import repl
+from .repl import repl, prompt
 from .target import get_target
 from .usage import usage
 
@@ -26,7 +26,9 @@ def main():
                 args = args[:-1]
         if not target:
             target = get_target()
-        cmd(target, ' '.join(args))
+        args = ' '.join(args)
+        print(f'{prompt(target)}{args}')
+        cmd(target, args)
     else:
         target = get_target(argv[1] if len(argv)>1 else None)
         repl(target)
