@@ -5,6 +5,9 @@ from setux.logger import info
 from setux.core.manage import Manager
 
 
+# pylint: disable=assignment-from-no-return
+
+
 class Service(Manager):
     def __init__(self, distro):
         super().__init__(distro)
@@ -17,9 +20,10 @@ class Service(Manager):
         info(f'\tservice {name} {"." if up else "X"}')
         return up
 
-    def wait(self, name):
+    def wait(self, name, up=True):
+        sleep(1)
         for _ in range(3):
-            if self.status(name): break
+            if self.status(name) is up: break
             sleep(3)
 
     def enable(self, name):
@@ -50,6 +54,7 @@ class Service(Manager):
         if self.status(svc):
             info(f'\tstop {name}')
             self.do_stop(svc)
+            self.wait(name, up=False)
 
     def restart(self, name):
         svc = self.svcmap.get(name, name)
