@@ -147,7 +147,11 @@ class Target:
 
         try:
             log('running "%s" ...', command)
-            proc = run(cmd, stdout=PIPE, stderr=PIPE, **kw)
+            try:
+                proc = run(cmd, stdout=PIPE, stderr=PIPE, **kw)
+            except OSError:
+                kw['shell'] = True
+                proc = run(cmd, stdout=PIPE, stderr=PIPE, **kw)
 
             out = proc.stdout.decode("utf-8").strip()
             if out:
