@@ -1,6 +1,13 @@
+from inspect import getsource
+
 from setux.logger import debug, error
 from setux.core.package import Packager
 
+try:
+    from . import pacman_bigs
+except Exception as x:
+    error(x)
+    raise
 
 # pylint: disable=expression-not-assigned
 
@@ -20,6 +27,21 @@ class Pacman(Packager):
                 yield name, ver
             except: pass
 
+    def do_bigs(self):
+        src = getsource(pacman_bigs)
+        ret, out, err = self.target.script(src)
+        for line in out:
+            yield line
+
+    def do_upgradable(self):
+        ret, out, err = self.run('pacman -Qu', report='quiet')
+        for line in out:
+            try:
+                name, ver = line.split(' ', 1)
+                yield name, ver
+            except Exception as x:
+                debug(line)
+
     def do_available(self):
         ret, out, err = self.run(f'pacman -Ssq', report='quiet')
         for line in out:
@@ -29,7 +51,7 @@ class Pacman(Packager):
             except: pass
 
     def do_remove(self, pkg):
-        self.run(f'pacman --no-confirm -Rs {pkg}')
+        self.run(f'pacman --noconfirm -Rs {pkg}')
 
     def do_cleanup(self):
         self.run('pacman --noconfirm -Rcsun $(pacman -Qdtq)')
