@@ -39,7 +39,7 @@ class Local(Target):
             out.write(content)
         return open(path, mode=mode.replace('w','r')).read() == content
 
-    def send(self, local, remote):
+    def send(self, local, remote, quiet=False):
         info(f'\tsend {local} -> {remote}')
         copy(local, remote)
 
